@@ -27,8 +27,11 @@
 #include "strdup.h"
 
 #include <nettle-types.h>
+#ifdef HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
 #ifdef HAVE_NETINET_IN_H
-#include <netinet/in.h>
+# include <netinet/in.h>
 #endif
 
 #define HEXCHAR(c) ((c & 0x0F) > 9 ? 'a' + (c & 0x0F) - 10 : '0' + (c & 0x0F))
@@ -909,6 +912,8 @@ _gsasl_digest_md5_client_step (Gsasl_session_ctx * sctx,
 
 	if (cb_qop)
 	  state->qop = cb_qop (sctx, state->qop);
+	else
+	  state->qop = GSASL_QOP_AUTH;
 
 	if (maxbuf == -1)
 	  maxbuf = MAXBUF_DEFAULT;
